@@ -6,6 +6,7 @@ from .response import (
     TemplateFormResponse,
     TurboFrameResponse,
     TurboFrameTemplateResponse,
+    TurboStreamIterableResponse,
     TurboStreamResponse,
     TurboStreamStreamingResponse,
     TurboStreamTemplateResponse,
@@ -21,6 +22,7 @@ __all__ = [
     "TurboFrameResponse",
     "TurboFrameTemplateResponse",
     "TurboStream",
+    "TurboStreamIterableResponse",
     "TurboStreamResponse",
     "TurboStreamStreamingResponse",
     "TurboStreamTemplateResponse",
